pub struct ConversationListItem {Show 22 fields
pub id: GroupId,
pub created_at_ns: i64,
pub membership_state: GroupMembershipState,
pub installations_last_checked: i64,
pub added_by_inbox_id: String,
pub welcome_sequence_id: Option<i64>,
pub dm_id: Option<String>,
pub rotated_at_ns: i64,
pub conversation_type: ConversationType,
pub is_commit_log_forked: Option<bool>,
pub message_id: Option<Vec<u8>>,
pub decrypted_message_bytes: Option<Vec<u8>>,
pub sent_at_ns: Option<i64>,
pub kind: Option<GroupMessageKind>,
pub sender_installation_id: Option<Vec<u8>>,
pub sender_inbox_id: Option<String>,
pub delivery_status: Option<DeliveryStatus>,
pub content_type: Option<ContentType>,
pub version_major: Option<i32>,
pub version_minor: Option<i32>,
pub authority_id: Option<String>,
pub sequence_id: Option<i64>,
}Expand description
Combined view of a group and its messages, now named conversation_list.
Fields
id: GroupIdgroup_id
created_at_ns: i64Based on timestamp of the welcome message
membership_state: GroupMembershipStateEnum, GroupMembershipState representing access to the group
installations_last_checked: i64Track when the latest, most recent installations were checked
added_by_inbox_id: StringThe inbox_id of who added the user to the group
welcome_sequence_id: Option<i64>The sequence id of the welcome message
dm_id: Option<String>concatenation of dm participant inbox_ids in alphanumeric order
rotated_at_ns: i64The last time the leaf node encryption key was rotated
conversation_type: ConversationTypeEnum, ConversationType signifies the group conversation type which extends to who can access it.
is_commit_log_forked: Option<bool>Whether the commit log for this conversation is forked
message_id: Option<Vec<u8>>Id of the message. Nullable because not every group has messages.
decrypted_message_bytes: Option<Vec<u8>>Contents of message after decryption.
sent_at_ns: Option<i64>Time in nanoseconds the message was sent.
kind: Option<GroupMessageKind>Group Message Kind Enum: 1 = Application, 2 = MembershipChange
sender_installation_id: Option<Vec<u8>>The ID of the App Installation this message was sent from.
sender_inbox_id: Option<String>The Inbox ID of the Sender
delivery_status: Option<DeliveryStatus>We optimistically store messages before sending.
content_type: Option<ContentType>The Content Type of the message
version_major: Option<i32>The content type version major
version_minor: Option<i32>The content type version minor
The ID of the authority defining the content type
sequence_id: Option<i64>sequence id of the message