pub struct UnencryptedConnection { /* private fields */ }Expand description
An Unencrypted Connection Creates a Sqlite3 Database/Connection in WAL mode. _NOTE:_Unencrypted Connections are not validated and mostly meant for testing. It is not recommended to use an unencrypted connection in production.
Implementations
Sourceimpl UnencryptedConnection
impl UnencryptedConnection
pub fn new(options: StorageOption) -> Self