#[repr(i32)]pub enum GroupMembershipState {
Allowed = 1,
Rejected = 2,
Pending = 3,
Restored = 4,
PendingRemove = 5,
}Expand description
Status of membership in a group, once a user sends a request to join
Variants
Allowed = 1
User is allowed to interact with this Group
Rejected = 2
User has been Rejected from this Group
Pending = 3
User is Pending acceptance to the Group
Restored = 4
Group has been restored from an archive, but is not active yet.
PendingRemove = 5
User is Pending to get removed of the Group