pub struct StoredGroupBuilder { /* private fields */ }Expand description
Builder for StoredGroup.
Implementations
Sourceimpl StoredGroupBuilder
impl StoredGroupBuilder
Sourcepub fn id<VALUE: Into<GroupId>>(&mut self, value: VALUE) -> &mut Self
pub fn id<VALUE: Into<GroupId>>(&mut self, value: VALUE) -> &mut Self
Randomly generated ID by group creator
Sourcepub fn created_at_ns<VALUE: Into<i64>>(&mut self, value: VALUE) -> &mut Self
pub fn created_at_ns<VALUE: Into<i64>>(&mut self, value: VALUE) -> &mut Self
Based on timestamp of this welcome message
Sourcepub fn membership_state<VALUE: Into<GroupMembershipState>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn membership_state<VALUE: Into<GroupMembershipState>>( &mut self, value: VALUE, ) -> &mut Self
Enum, GroupMembershipState representing access to the group
Sourcepub fn installations_last_checked<VALUE: Into<i64>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn installations_last_checked<VALUE: Into<i64>>( &mut self, value: VALUE, ) -> &mut Self
Track when the latest, most recent installations were checked
Sourcepub fn added_by_inbox_id<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn added_by_inbox_id<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
The inbox_id of who added the user to a group.
Sourcepub fn sequence_id<VALUE: Into<Option<i64>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn sequence_id<VALUE: Into<Option<i64>>>( &mut self, value: VALUE, ) -> &mut Self
The sequence id of the welcome message
Sourcepub fn rotated_at_ns<VALUE: Into<i64>>(&mut self, value: VALUE) -> &mut Self
pub fn rotated_at_ns<VALUE: Into<i64>>(&mut self, value: VALUE) -> &mut Self
The last time the leaf node encryption key was rotated
Sourcepub fn conversation_type<VALUE: Into<ConversationType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn conversation_type<VALUE: Into<ConversationType>>( &mut self, value: VALUE, ) -> &mut Self
Enum, ConversationType signifies the group conversation type which extends to who can access it.
Sourcepub fn dm_id<VALUE: Into<Option<String>>>(&mut self, value: VALUE) -> &mut Self
pub fn dm_id<VALUE: Into<Option<String>>>(&mut self, value: VALUE) -> &mut Self
The inbox_id of the DM target
Sourcepub fn last_message_ns<VALUE: Into<Option<i64>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn last_message_ns<VALUE: Into<Option<i64>>>( &mut self, value: VALUE, ) -> &mut Self
Timestamp of when the last message was sent for this group (updated automatically in a trigger)
Sourcepub fn message_disappear_from_ns<VALUE: Into<Option<i64>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn message_disappear_from_ns<VALUE: Into<Option<i64>>>( &mut self, value: VALUE, ) -> &mut Self
The Time in NS when the messages should be deleted
Sourcepub fn message_disappear_in_ns<VALUE: Into<Option<i64>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn message_disappear_in_ns<VALUE: Into<Option<i64>>>( &mut self, value: VALUE, ) -> &mut Self
How long a message in the group can live in NS
Sourcepub fn paused_for_version<VALUE: Into<Option<String>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn paused_for_version<VALUE: Into<Option<String>>>( &mut self, value: VALUE, ) -> &mut Self
The version of the protocol that the group is paused for, None is not paused
pub fn maybe_forked<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn fork_details<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Sourcepub fn should_publish_commit_log<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn should_publish_commit_log<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Whether the user should publish the commit log for this group
Sourcepub fn commit_log_public_key<VALUE: Into<Option<Vec<u8>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn commit_log_public_key<VALUE: Into<Option<Vec<u8>>>>( &mut self, value: VALUE, ) -> &mut Self
The consensus public key of the commit log for this group Derived from the first entry of the commit log
Sourcepub fn is_commit_log_forked<VALUE: Into<Option<bool>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn is_commit_log_forked<VALUE: Into<Option<bool>>>( &mut self, value: VALUE, ) -> &mut Self
Whether the local commit log has diverged from the remote commit log NULL if the remote commit log is not up to date yet
Sourcepub fn has_pending_leave_request<VALUE: Into<Option<bool>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn has_pending_leave_request<VALUE: Into<Option<bool>>>( &mut self, value: VALUE, ) -> &mut Self
Whether the pending-remove list is empty NULL if the pending-remove didn’t receive an update yet
Sourcepub fn push_override<VALUE: Into<Option<i32>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn push_override<VALUE: Into<Option<i32>>>( &mut self, value: VALUE, ) -> &mut Self
Optional notification rule for this conversation.
Sourcepub fn build(&self) -> Result<StoredGroup, StorageError>
pub fn build(&self) -> Result<StoredGroup, StorageError>