pub struct NewGroupIntent {
pub kind: IntentKind,
pub group_id: GroupId,
pub data: Vec<u8>,
pub should_push: bool,
pub state: IntentState,
}Expand description
NewGroupIntent is the data needed to create a new group intent.
Do not use this struct directly outside of the storage module.
Use the queue_intent method on MlsGroup instead.
Fields
kind: IntentKindgroup_id: GroupIddata: Vec<u8>should_push: boolstate: IntentStateImplementations