StoredGroupMessage

Struct StoredGroupMessage 

pub struct StoredGroupMessage {
Show 20 fields pub id: Vec<u8>, pub group_id: GroupId, pub decrypted_message_bytes: Vec<u8>, pub sent_at_ns: i64, pub kind: GroupMessageKind, pub sender_installation_id: Vec<u8>, pub sender_inbox_id: String, pub delivery_status: DeliveryStatus, pub content_type: ContentType, pub version_major: i32, pub version_minor: i32, pub authority_id: String, pub reference_id: Option<Vec<u8>>, pub sequence_id: i64, pub envelope_hash: Option<Vec<u8>>, pub expiry_ns: Option<i64>, pub inserted_at_ns: i64, pub expire_at_ns: Option<i64>, pub should_push: bool, pub idempotency_key: String,
}
Successfully processed messages to be returned to the User.

Fields

id: Vec<u8>

Id of the message.

group_id: GroupId

Id of the group this message is tied to.

decrypted_message_bytes: Vec<u8>

Contents of message after decryption.

sent_at_ns: i64

Time in nanoseconds the message was sent.

kind: GroupMessageKind

Group Message Kind Enum: 1 = Application, 2 = MembershipChange

sender_installation_id: Vec<u8>

The ID of the App Installation this message was sent from.

sender_inbox_id: String

The Inbox ID of the Sender

delivery_status: DeliveryStatus

We optimistically store messages before sending.

content_type: ContentType

The Content Type of the message

version_major: i32

The content type version major

version_minor: i32

The content type version minor

authority_id: String

The ID of the authority defining the content type

reference_id: Option<Vec<u8>>

The ID of a referenced message

sequence_id: i64

The Message SequenceId

envelope_hash: Option<Vec<u8>>

Canonical envelope hash assigned by the backend.

expiry_ns: Option<i64>

Backend retention metadata. This does not control message deletion.

inserted_at_ns: i64

Time in nanoseconds the message was inserted into the database This field is automatically set by the database

expire_at_ns: Option<i64>

Timestamp (in NS) after which the message must be deleted

should_push: bool

Whether to send a push notification when publishing this message

idempotency_key: String

The idempotency key the message id is derived from. Defaults to the send timestamp, but callers may supply their own to make retries idempotent.

Implementations