pub enum JoinAnchorMode {
Advance,
InactiveReadd,
}Expand description
The group-state proof required to install a validated Welcome’s anchor.
Variants
Advance
The anchor must advance an existing processed position.
InactiveReadd
The caller proved that an inactive group has a newer re-add Welcome. Its anchor must equal the processed removal position in the same transaction.