pub enum NetworkEntityKind {
Welcome,
Group,
Identity,
}Expand description
Separate network queues with independent pending-work budgets.
Variants
Welcome
Independent Welcome work for an installation.
Group
One ordered queue for both group commits and application messages.
Identity
Ordered identity updates needed by group and Welcome processing.
Implementations
Sourceimpl NetworkEntityKind
impl NetworkEntityKind
pub fn entity_kind(self) -> EntityKind