StoredMessageDeletion

Struct StoredMessageDeletion 

pub struct StoredMessageDeletion {
    pub id: Vec<u8>,
    pub group_id: GroupId,
    pub deleted_message_id: Vec<u8>,
    pub deleted_by_inbox_id: String,
    pub is_super_admin_deletion: bool,
    pub deleted_at_ns: i64,
}
Represents a deletion record for a message in a group conversation

Fields

id: Vec<u8>

The ID of the DeleteMessage in the group_messages table

group_id: GroupId

The group this deletion belongs to

deleted_message_id: Vec<u8>

The ID of the original message being deleted

deleted_by_inbox_id: String

The inbox_id of who sent the delete message

is_super_admin_deletion: bool

Whether the deleter was a super admin at deletion time

deleted_at_ns: i64

Timestamp when the deletion was processed