pub struct PendingRemove {
pub group_id: GroupId,
pub inbox_id: String,
pub message_id: Vec<u8>,
}Fields
group_id: GroupIdId of the group this message is tied to.
inbox_id: StringId of the inbox user want to leave the group.
message_id: Vec<u8>Id of the LeaveRequest message