pub trait ConnectionExt: MaybeSend + MaybeSync {
// Required methods
fn raw_query<T, F>(&self, fun: F) -> Result<T, ConnectionError>
where F: FnOnce(&mut SqliteConnection) -> Result<T, Error>,
Self: Sized;
fn disconnect(&self) -> Result<(), ConnectionError>;
fn reconnect(&self) -> Result<(), ConnectionError>;
}Required Methods
Sourcefn raw_query<T, F>(&self, fun: F) -> Result<T, ConnectionError>
fn raw_query<T, F>(&self, fun: F) -> Result<T, ConnectionError>
Run a scoped query against the underlying SQLite connection.
fn disconnect(&self) -> Result<(), ConnectionError>
fn reconnect(&self) -> Result<(), ConnectionError>
Implementations on Foreign Types
Sourceimpl ConnectionExt for Infallible
std::convert::Infallible is used as the Single type parameter on targets
(wasm) that have no single-connection mode. It is uninhabited, so the
Single arm is statically impossible to construct.
impl ConnectionExt for Infallible
std::convert::Infallible is used as the Single type parameter on targets
(wasm) that have no single-connection mode. It is uninhabited, so the
Single arm is statically impossible to construct.